@@ -19,7 +19,8 @@ class MapInfoAction(ActionInterface):
         super(MapInfoAction, self).__init__()
 
     def run(self, response: ActionResponse):
-        pass
+        if response.cid == 901:
+            self.load_point(response.data)
 
     def load_point(self, point_json):
         for point in point_json['pointList']:
